==> haskell-fsnotify-0.3.0.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.3.0.1
id: fsnotify-0.3.0.1-JzZRVhdXZks8sGTzd8bcuU
key: fsnotify-0.3.0.1-JzZRVhdXZks8sGTzd8bcuU
license: BSD-3-Clause
maintainer: Tom McLaughlin <tom@codedown.io>
author: Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
abi: 338aa215b85deaf9a8ea2100e190ebd4
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/fsnotify-0.3.0.1
hs-libraries: HSfsnotify-0.3.0.1-JzZRVhdXZks8sGTzd8bcuU
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2 text-1.2.3.0 time-1.8.0.2
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi
    shelly-1.8.1-KQF6m5b84wx2spmAXR44v8 unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi=ab9a7ffd21f0ec5d7d17bb8be4fa9bb3
             shelly-1.8.1-KQF6m5b84wx2spmAXR44v8=74ea85fa91fb4e9c94e88d7dca7ec71d
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.3.0.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.3.0.1
id: fsnotify-0.3.0.1-BxS2bfn2bSKDSzdrSV5Mbk
key: fsnotify-0.3.0.1-BxS2bfn2bSKDSzdrSV5Mbk
license: BSD-3-Clause
maintainer: Tom McLaughlin <tom@codedown.io>
author: Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
abi: 54bb6207f35735d4c466d9a3b91e0219
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/fsnotify-0.3.0.1
hs-libraries: HSfsnotify-0.3.0.1-BxS2bfn2bSKDSzdrSV5Mbk
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2 text-1.2.3.0 time-1.8.0.2
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi
    shelly-1.8.1-KcAnGTfaYb5scR8anWZJP unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi=ab9a7ffd21f0ec5d7d17bb8be4fa9bb3
             shelly-1.8.1-KcAnGTfaYb5scR8anWZJP=aa230d31ab82d334da4e44c8eba73333
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
